@@ -11,7 +11,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: CodeSniffer.php,v 1.68 2008/02/01 03:00:03 squiz Exp $
+ * @version   CVS: $Id: CodeSniffer.php,v 1.75 2008/06/30 04:58:38 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -69,7 +69,7 @@ class PHP_CodeSniffer
     protected $file = array();
 
     /**
-     * The directory where to search for tests.
+     * The directory to search for sniffs in.
      *
      * @var string
      */
@@ -101,10 +101,11 @@ class PHP_CodeSniffer
      *
      * @var array
      */
-    protected $allowedFileExtensions = array(
-                                        'php',
-                                        'inc',
-                                       );
+    public $allowedFileExtensions = array(
+                                     'php' => 'PHP',
+                                     'inc' => 'PHP',
+                                     'js'  => 'JS',
+                                    );
 
     /**
      * An array of variable types for param/var we will check.
@@ -180,13 +181,26 @@ class PHP_CodeSniffer
     /**
      * Sets an array of file extensions that we will allow checking of.
      *
+     * If the extension is one of the defaults, a specific tokenizer
+     * will be used. Otherwise, the PHP tokenizer will be used for
+     * all extensions passed.
+     *
      * @param array $extensions An array of file extensions.
      *
      * @return void
      */
     public function setAllowedFileExtensions(array $extensions)
     {
-        $this->allowedFileExtensions = $extensions;
+        $newExtensions = array();
+        foreach ($extensions as $ext) {
+            if (isset($this->allowedFileExtensions[$ext]) === true) {
+                $newExtensions[$ext] = $this->allowedFileExtensions[$ext];
+            } else {
+                $newExtensions[$ext] = 'PHP';
+            }
+        }
+
+        $this->allowedFileExtensions = $newExtensions;
 
     }//end setAllowedFileExtensions()
 
@@ -207,6 +221,22 @@ class PHP_CodeSniffer
     }//end setIgnorePatterns()
 
 
+    /**
+     * Adds a file to the list of checked files.
+     *
+     * Checked files are used to generate error reports after the run.
+     *
+     * @param PHP_CodeSniffer_File $phpcsFile The file to add.
+     *
+     * @return void
+     */
+    public function addFile(PHP_CodeSniffer_File $phpcsFile)
+    {
+        $this->files[] = $phpcsFile;
+
+    }//end addFile()
+
+
     /**
      * Processes the files/directories that PHP_CodeSniffer was constructed with.
      *
@@ -236,14 +266,6 @@ class PHP_CodeSniffer
             throw new PHP_CodeSniffer_Exception('$standard must be a string');
         }
 
-        if (is_dir($standard) === true) {
-            // This is a custom standard.
-            $this->standardDir = $standard;
-            $standard          = basename($standard);
-        } else {
-            $this->standardDir = realpath(dirname(__FILE__).'/CodeSniffer/Standards/'.$standard);
-        }
-
         // Reset the members.
         $this->listeners = array();
         $this->files     = array();
@@ -255,7 +277,7 @@ class PHP_CodeSniffer
             }
         }
 
-        $this->registerTokenListeners($standard, $sniffs);
+        $this->setTokenListeners($standard, $sniffs);
         if (PHP_CODESNIFFER_VERBOSITY > 0) {
             $numSniffs = count($this->listeners);
             echo "DONE ($numSniffs sniffs registered)".PHP_EOL;
@@ -274,22 +296,32 @@ class PHP_CodeSniffer
 
 
     /**
-     * Registers installed sniffs in the coding standard being used.
+     * Gets installed sniffs in the coding standard being used.
      *
      * Traverses the standard directory for classes that implement the
      * PHP_CodeSniffer_Sniff interface asks them to register. Each of the
      * sniff's class names must be exact as the basename of the sniff file.
      *
+     * Returns an array of sniff class names.
+     *
      * @param string $standard The name of the coding standard we are checking.
      * @param array  $sniffs   The sniff names to restrict the allowed
      *                         listeners to.
      *
-     * @return void
+     * @return array
      * @throws PHP_CodeSniffer_Exception If any of the tests failed in the
      *                                   registration process.
      */
-    protected function registerTokenListeners($standard, array $sniffs=array())
+    public function getTokenListeners($standard, array $sniffs=array())
     {
+        if (is_dir($standard) === true) {
+            // This is a custom standard.
+            $this->standardDir = $standard;
+            $standard          = basename($standard);
+        } else {
+            $this->standardDir = realpath(dirname(__FILE__).'/CodeSniffer/Standards/'.$standard);
+        }
+
         $files = self::getSniffFiles($this->standardDir, $standard);
 
         if (empty($sniffs) === false) {
@@ -300,8 +332,9 @@ class PHP_CodeSniffer
             }
         }
 
-        foreach ($files as $file) {
+        $listeners = array();
 
+        foreach ($files as $file) {
             // Work out where the position of /StandardName/Sniffs/... is
             // so we can determine what the class will be called.
             $sniffPos = strrpos($file, DIRECTORY_SEPARATOR.'Sniffs'.DIRECTORY_SEPARATOR);
@@ -327,14 +360,32 @@ class PHP_CodeSniffer
                 continue;
             }
 
-            $this->listeners[] = $className;
+            $listeners[] = $className;
 
             if (PHP_CODESNIFFER_VERBOSITY > 2) {
                 echo "\tRegistered $className".PHP_EOL;
             }
         }//end foreach
 
-    }//end registerTokenListeners()
+        return $listeners;
+
+    }//end getTokenListeners()
+
+
+    /**
+     * Sets installed sniffs in the coding standard being used.
+     *
+     * @param string $standard The name of the coding standard we are checking.
+     * @param array  $sniffs   The sniff names to restrict the allowed
+     *                         listeners to.
+     *
+     * @return null
+     */
+    public function setTokenListeners($standard, array $sniffs=array())
+    {
+        $this->listeners = $this->getTokenListeners($standard, $sniffs);
+
+    }//end setTokenListeners
 
 
     /**
@@ -482,38 +533,49 @@ class PHP_CodeSniffer
      * @return void
      * @throws Exception If there was an error opening the directory.
      */
-    protected function processFiles($dir, $local=false)
+    public function processFiles($dir, $local=false)
     {
-        if ($local === true) {
-            $di = new DirectoryIterator($dir);
-        } else {
-            $di = new RecursiveIteratorIterator(new RecursiveDirectoryIterator($dir));
+        try {
+            if ($local === true) {
+                $di = new DirectoryIterator($dir);
+            } else {
+                $di = new RecursiveIteratorIterator(new RecursiveDirectoryIterator($dir));
+            }
+
+            foreach ($di as $file) {
+                $filePath = realpath($file->getPathname());
+
+                if (is_dir($filePath) === true) {
+                    continue;
+                }
+
+                // Check that the file's extension is one we are checking.
+                // Note that because we are doing a whole directory, we
+                // are strick about checking the extension and we don't
+                // let files with no extension through.
+                $fileParts = explode('.', $file);
+                $extension = array_pop($fileParts);
+                if ($extension === $file) {
+                    continue;
+                }
+
+                if (isset($this->allowedFileExtensions[$extension]) === false) {
+                    continue;
+                }
+
+                $this->processFile($filePath);
+            }//end foreach
+        } catch (Exception $e) {
+            $trace    = $e->getTrace();
+            $filename = $trace[0]['args'][0];
+            $error    = 'An error occurred during processing; checking has been aborted. The error message was: '.$e->getMessage();
+
+            $phpcsFile = new PHP_CodeSniffer_File($filename, $this->listeners, $this->allowedFileExtensions);
+            $this->addFile($phpcsFile);
+            $phpcsFile->addError($error, null);
+            return;
         }
 
-        foreach ($di as $file) {
-            $filePath = realpath($file->getPathname());
-
-            if (is_dir($filePath) === true) {
-                continue;
-            }
-
-            // Check that the file's extension is one we are checking.
-            // Note that because we are doing a whole directory, we
-            // are strick about checking the extension and we don't
-            // let files with no extension through.
-            $fileParts = explode('.', $file);
-            $extension = array_pop($fileParts);
-            if ($extension === $file) {
-                continue;
-            }
-
-            if (in_array($extension, $this->allowedFileExtensions) === false) {
-                continue;
-            }
-
-            $this->processFile($filePath);
-        }//end foreach
-
     }//end processFiles()
 
 
@@ -523,14 +585,16 @@ class PHP_CodeSniffer
      * Processes the file and runs the PHP_CodeSniffer sniffs to verify that it
      * conforms with the standard.
      *
-     * @param string $file The file to process.
+     * @param string $file     The file to process.
+     * @param string $contents The contents to parse. If NULL, the content
+     *                         is taken from the file system.
      *
      * @return void
      * @throws PHP_CodeSniffer_Exception If the file could not be processed.
      */
-    protected function processFile($file)
+    public function processFile($file, $contents=null)
     {
-        if (file_exists($file) === false) {
+        if (is_null($contents) === true && file_exists($file) === false) {
             throw new PHP_CodeSniffer_Exception("Source file $file does not exist");
         }
 
@@ -555,9 +619,9 @@ class PHP_CodeSniffer
             }
         }
 
-        $phpcsFile     = new PHP_CodeSniffer_File($file, $this->listeners);
-        $this->files[] = $phpcsFile;
-        $phpcsFile->start();
+        $phpcsFile = new PHP_CodeSniffer_File($file, $this->listeners, $this->allowedFileExtensions);
+        $this->addFile($phpcsFile);
+        $phpcsFile->start($contents);
 
         if (PHP_CODESNIFFER_VERBOSITY > 0) {
             $timeTaken = (time() - $startTime);
@@ -700,7 +764,6 @@ class PHP_CodeSniffer
 
         $report = $this->prepareErrorReport($showWarnings);
         foreach ($report['files'] as $filename => $file) {
-
             if (empty($file['messages']) === true) {
                 continue;
             }
@@ -747,7 +810,6 @@ class PHP_CodeSniffer
 
         $report = $this->prepareErrorReport($showWarnings);
         foreach ($report['files'] as $filename => $file) {
-
             echo ' <file name="'.$filename.'">'.PHP_EOL;
 
             foreach ($file['messages'] as $line => $lineErrors) {
@@ -791,7 +853,6 @@ class PHP_CodeSniffer
 
         $report = $this->prepareErrorReport($showWarnings);
         foreach ($report['files'] as $filename => $file) {
-
             foreach ($file['messages'] as $line => $lineErrors) {
                 foreach ($lineErrors as $column => $colErrors) {
                     foreach ($colErrors as $error) {
@@ -803,7 +864,6 @@ class PHP_CodeSniffer
                     }
                 }
             }//end foreach
-
         }//end foreach
 
         return $errorsShown;
@@ -826,7 +886,6 @@ class PHP_CodeSniffer
 
         $report = $this->prepareErrorReport($showWarnings);
         foreach ($report['files'] as $filename => $file) {
-
             if (empty($file['messages']) === true) {
                 continue;
             }
@@ -1392,7 +1451,6 @@ class PHP_CodeSniffer
                 // Must be a custom type name.
                 return $varType;
             }//end if
-
         }//end if
 
     }//end suggestType()
