@@ -10,7 +10,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: AbstractPatternSniff.php,v 1.19 2008/02/01 03:19:53 squiz Exp $
+ * @version   CVS: $Id: AbstractPatternSniff.php,v 1.23 2008/06/13 02:25:39 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -30,7 +30,7 @@ if (class_exists('PHP_CodeSniffer_Standards_IncorrectPatternException', true) ==
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.0.1
+ * @version   Release: 1.1.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_CodeSniffer_Sniff
@@ -57,7 +57,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
      *
      * @var boolean
      */
-    private $_ignoreComments = true;
+    private $_ignoreComments = false;
 
     /**
      * Positions in the stack where errors have occured.
@@ -244,7 +244,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
 
 
     /**
-     * Processes the pattern and varifies the code at $stackPtr.
+     * Processes the pattern and verifies the code at $stackPtr.
      *
      * @param array                $patternInfo Information about the pattern used
      *                                          for checking, which includes are
@@ -390,7 +390,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
                             $tokenContent = $tokens[$stackPtr]['content'];
                         } else {
                             // Get all the whitespace to the next token.
-                            $next              = $phpcsFile->findNext(T_WHITESPACE, $stackPtr, null, true);
+                            $next              = $phpcsFile->findNext(PHP_CodeSniffer_Tokens::$emptyTokens, $stackPtr, null, true);
                             $tokenContent      = $phpcsFile->getTokensAsString($stackPtr, ($next - $stackPtr));
                             $lastAddedStackPtr = $stackPtr;
                             $stackPtr          = $next;
@@ -434,7 +434,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
                         $hasComment = false;
                         for ($j = $stackPtr; $j < $next; $j++) {
                             $found .= $tokens[$j]['content'];
-                            if ($tokens[$j]['code'] === T_COMMENT) {
+                            if (in_array($tokens[$j]['code'], PHP_CodeSniffer_Tokens::$commentTokens) === true) {
                                 $hasComment = true;
                             }
                         }
@@ -476,7 +476,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
                     return false;
                 }
 
-                $found = '...';
+                $found .= '...';
                 if ($pattern[$i]['to'] === 'parenthesis_closer') {
                     $found .= ')';
                 } else {
@@ -536,7 +536,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
                 if ($stackPtr !== $lastAddedStackPtr) {
                     $found            .= $phpcsFile->getTokensAsString($stackPtr, ($next - $stackPtr));
                     $diff              = ($next - $stackPtr);
-                    $lastAddedStackPtr = $next;
+                    $lastAddedStackPtr = ($next - 1);
                 }
 
                 $stackPtr = $next;
@@ -566,6 +566,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
         $found    = str_replace("\r\n", '\n', $found);
         $found    = str_replace("\n", '\n', $found);
         $found    = str_replace("\r", '\n', $found);
+        $found    = str_replace('EOL', '\n', $found);
         $expected = str_replace('EOL', '\n', $patternCode);
 
         $error = "Expected \"$expected\"; found \"$found\"";
