@@ -10,7 +10,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: DisallowTabIndentUnitTest.php,v 1.1 2007/08/02 23:18:31 squiz Exp $
+ * @version   CVS: $Id: DisallowTabIndentUnitTest.php,v 1.2 2008/02/20 05:25:34 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -26,7 +26,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.0.1
+ * @version   Release: 1.1.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Tests_WhiteSpace_DisallowTabIndentUnitTest extends AbstractSniffUnitTest
@@ -39,15 +39,30 @@ class Generic_Tests_WhiteSpace_DisallowTabIndentUnitTest extends AbstractSniffUn
      * The key of the array should represent the line number and the value
      * should represent the number of errors that should occur on that line.
      *
+     * @param string $testFile The name of the file being tested.
+     *
      * @return array(int => int)
      */
-    public function getErrorList()
+    public function getErrorList($testFile='DisallowTabIndentUnitTest.inc')
     {
-        return array(
-                5  => 1,
-                9  => 1,
-                15 => 1,
-               );
+        switch ($testFile) {
+        case 'DisallowTabIndentUnitTest.inc':
+            return array(
+                    5  => 1,
+                    9  => 1,
+                    15 => 1,
+                   );
+            break;
+        case 'DisallowTabIndentUnitTest.js':
+            return array(
+                    5  => 1,
+                    10 => 1,
+                   );
+            break;
+        default:
+            return array();
+            break;
+        }//end switch
 
     }//end getErrorList()
 
