@@ -10,7 +10,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: FileCommentSniff.php,v 1.25 2007/11/26 22:11:18 squiz Exp $
+ * @version   CVS: $Id: FileCommentSniff.php,v 1.26 2008/06/20 05:37:05 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -39,7 +39,7 @@ if (class_exists('PHP_CodeSniffer_CommentParser_ClassCommentParser', true) === f
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.0.1
+ * @version   Release: 1.1.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -60,6 +60,69 @@ class PEAR_Sniffs_Commenting_FileCommentSniff implements PHP_CodeSniffer_Sniff
      */
     protected $currentFile = null;
 
+    /**
+     * Tags in correct order and related info.
+     *
+     * @var array
+     */
+    protected $tags = array(
+                       'category'   => array(
+                                        'required'       => true,
+                                        'allow_multiple' => false,
+                                        'order_text'     => 'precedes @package',
+                                       ),
+                       'package'    => array(
+                                        'required'       => true,
+                                        'allow_multiple' => false,
+                                        'order_text'     => 'follows @category',
+                                       ),
+                       'subpackage' => array(
+                                        'required'       => false,
+                                        'allow_multiple' => false,
+                                        'order_text'     => 'follows @package',
+                                       ),
+                       'author'     => array(
+                                        'required'       => true,
+                                        'allow_multiple' => true,
+                                        'order_text'     => 'follows @subpackage (if used) or @package',
+                                       ),
+                       'copyright'  => array(
+                                        'required'       => false,
+                                        'allow_multiple' => true,
+                                        'order_text'     => 'follows @author',
+                                       ),
+                       'license'    => array(
+                                        'required'       => true,
+                                        'allow_multiple' => false,
+                                        'order_text'     => 'follows @copyright (if used) or @author',
+                                       ),
+                       'version'    => array(
+                                        'required'       => false,
+                                        'allow_multiple' => false,
+                                        'order_text'     => 'follows @licence',
+                                       ),
+                       'link'       => array(
+                                        'required'       => true,
+                                        'allow_multiple' => true,
+                                        'order_text'     => 'follows @version',
+                                       ),
+                       'see'        => array(
+                                        'required'       => false,
+                                        'allow_multiple' => true,
+                                        'order_text'     => 'follows @link',
+                                       ),
+                       'since'      => array(
+                                        'required'       => false,
+                                        'allow_multiple' => false,
+                                        'order_text'     => 'follows @see (if used) or @link',
+                                       ),
+                       'deprecated' => array(
+                                        'required'       => false,
+                                        'allow_multiple' => false,
+                                        'order_text'     => 'follows @since (if used) or @see (if used) or @link',
+                                       ),
+                );
+
 
     /**
      * Returns an array of tokens this test wants to listen for.
@@ -222,65 +285,6 @@ class PEAR_Sniffs_Commenting_FileCommentSniff implements PHP_CodeSniffer_Sniff
      */
     protected function processTags($commentStart, $commentEnd)
     {
-        // Tags in correct order and related info.
-        $tags = array(
-                 'category'   => array(
-                                  'required'       => true,
-                                  'allow_multiple' => false,
-                                  'order_text'     => 'precedes @package',
-                                 ),
-                 'package'    => array(
-                                  'required'       => true,
-                                  'allow_multiple' => false,
-                                  'order_text'     => 'follows @category',
-                                 ),
-                 'subpackage' => array(
-                                  'required'       => false,
-                                  'allow_multiple' => false,
-                                  'order_text'     => 'follows @package',
-                                 ),
-                 'author'     => array(
-                                  'required'       => true,
-                                  'allow_multiple' => true,
-                                  'order_text'     => 'follows @subpackage (if used) or @package',
-                                 ),
-                 'copyright'  => array(
-                                  'required'       => false,
-                                  'allow_multiple' => true,
-                                  'order_text'     => 'follows @author',
-                                 ),
-                 'license'    => array(
-                                  'required'       => true,
-                                  'allow_multiple' => false,
-                                  'order_text'     => 'follows @copyright (if used) or @author',
-                                 ),
-                 'version'    => array(
-                                  'required'       => false,
-                                  'allow_multiple' => false,
-                                  'order_text'     => 'follows @licence',
-                                 ),
-                 'link'       => array(
-                                  'required'       => true,
-                                  'allow_multiple' => true,
-                                  'order_text'     => 'follows @version',
-                                 ),
-                 'see'        => array(
-                                  'required'       => false,
-                                  'allow_multiple' => true,
-                                  'order_text'     => 'follows @link',
-                                 ),
-                 'since'      => array(
-                                  'required'       => false,
-                                  'allow_multiple' => false,
-                                  'order_text'     => 'follows @see (if used) or @link',
-                                 ),
-                 'deprecated' => array(
-                                  'required'       => false,
-                                  'allow_multiple' => false,
-                                  'order_text'     => 'follows @since (if used) or @see (if used) or @link',
-                                 ),
-                );
-
         $docBlock    = (get_class($this) === 'PEAR_Sniffs_Commenting_FileCommentSniff') ? 'file' : 'class';
         $foundTags   = $this->commentParser->getTagOrders();
         $orderIndex  = 0;
@@ -288,7 +292,7 @@ class PEAR_Sniffs_Commenting_FileCommentSniff implements PHP_CodeSniffer_Sniff
         $longestTag  = 0;
         $errorPos    = 0;
 
-        foreach ($tags as $tag => $info) {
+        foreach ($this->tags as $tag => $info) {
 
             // Required tag missing.
             if ($info['required'] === true && in_array($tag, $foundTags) === false) {
@@ -395,7 +399,7 @@ class PEAR_Sniffs_Commenting_FileCommentSniff implements PHP_CodeSniffer_Sniff
                 $error        = "@$indentInfo[tag] tag comment indented incorrectly. ";
                 $error       .= "Expected $expected spaces but found $space.";
                 $getTagMethod = 'get'.ucfirst($indentInfo['tag']);
-                if ($tags[$indentInfo['tag']]['allow_multiple'] === true) {
+                if ($this->tags[$indentInfo['tag']]['allow_multiple'] === true) {
                     $line = $indentInfo['line'];
                 } else {
                     $tagElem = $this->commentParser->$getTagMethod();
