@@ -10,7 +10,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: ValidClassNameSniff.php,v 1.8 2007/11/04 22:29:51 squiz Exp $
+ * @version   CVS: $Id: ValidClassNameSniff.php,v 1.10 2008/04/28 01:02:28 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -26,7 +26,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.0.1
+ * @version   Release: 1.1.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PEAR_Sniffs_NamingConventions_ValidClassNameSniff implements PHP_CodeSniffer_Sniff
@@ -87,16 +87,22 @@ class PEAR_Sniffs_NamingConventions_ValidClassNameSniff implements PHP_CodeSniff
             // to be incorrect.
             $nameBits = explode('_', trim($name, '_'));
             $firstBit = array_shift($nameBits);
+            if ($firstBit === '') {
+                $error = ucfirst($tokens[$stackPtr]['content']).' name is not valid';
+            } else {
+                $newName = strtoupper($firstBit{0}).substr($firstBit, 1).'_';
+                foreach ($nameBits as $bit) {
+                    if ($bit !== '') {
+                        $newName .= strtoupper($bit{0}).substr($bit, 1).'_';
+                    }
+                }
 
-            $newName = strtoupper($firstBit{0}).substr($firstBit, 1).'_';
-            foreach ($nameBits as $bit) {
-                $newName .= strtoupper($bit{0}).substr($bit, 1).'_';
+                $newName = rtrim($newName, '_');
+                $error   = ucfirst($tokens[$stackPtr]['content'])." name is not valid; consider $newName instead";
             }
 
-            $newName = rtrim($newName, '_');
-            $error   = ucfirst($tokens[$stackPtr]['content'])." name is not valid; consider $newName instead";
             $phpcsFile->addError($error, $stackPtr);
-        }
+        }//end if
 
     }//end process()
 
