@@ -10,7 +10,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: ArrayDeclarationSniff.php,v 1.17 2008/01/19 10:33:58 squiz Exp $
+ * @version   CVS: $Id: ArrayDeclarationSniff.php,v 1.19 2008/06/30 05:26:24 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -23,7 +23,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.0.1
+ * @version   Release: 1.1.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
@@ -37,9 +37,7 @@ class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
      */
     public function register()
     {
-        return array(
-                T_ARRAY,
-               );
+        return array(T_ARRAY);
 
     }//end register()
 
@@ -229,7 +227,7 @@ class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
 
                     // Find the value, which will be the first token on the line,
                     // excluding the leading whitespace.
-                    $valueContent = ($nextToken - 1);
+                    $valueContent = $phpcsFile->findPrevious(PHP_CodeSniffer_Tokens::$emptyTokens, ($nextToken - 1), null, true);
                     while ($tokens[$valueContent]['line'] === $tokens[$nextToken]['line']) {
                         if ($valueContent === $arrayStart) {
                             // Value must have been on the same line as the array
@@ -241,9 +239,7 @@ class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
                     }
 
                     $valueContent = $phpcsFile->findNext(T_WHITESPACE, ($valueContent + 1), $nextToken, true);
-                    $indices[]    = array(
-                                     'value' => $valueContent,
-                                    );
+                    $indices[]    = array('value' => $valueContent);
                     $singleUsed   = true;
                 }//end if
 
@@ -341,6 +337,13 @@ class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
             }
 
             foreach ($indices as $value) {
+                if (empty($value['value']) === true) {
+                    // Array was malformed and we couldn't figure out
+                    // the array value correctly, so we have to ignore it.
+                    // Other parts of this sniff will correct the error.
+                    continue;
+                }
+
                 if ($tokens[($value['value'] - 1)]['code'] === T_WHITESPACE) {
                     // A whitespace token before this value means that the value
                     // was indented and not flush with the opening parenthesis.
@@ -388,6 +391,16 @@ class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
                 continue;
             }
 
+            if (isset($index['index_content']) === true) {
+                $indexContent = trim($index['index_content'], "'");
+                if (preg_match('|^[a-zA-Z0-9_]+$|', $indexContent) === 1) {
+                    if (strtolower($indexContent) !== $indexContent) {
+                        $error = 'Array index "'.$indexContent.'" should not contain uppercase characters';
+                        $phpcsFile->addError($error, $index['index']);
+                    }
+                }
+            }
+
             if (($tokens[$index['index']]['line'] === $tokens[$stackPtr]['line'])) {
                 $phpcsFile->addError('The first index in a multi-value array must be on a new line', $stackPtr);
                 continue;
