@@ -10,7 +10,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: BlockCommentSniff.php,v 1.7 2007/11/04 22:29:51 squiz Exp $
+ * @version   CVS: $Id: BlockCommentSniff.php,v 1.11 2008/02/26 04:03:14 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -25,7 +25,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.0.1
+ * @version   Release: 1.1.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_Commenting_BlockCommentSniff implements PHP_CodeSniffer_Sniff
@@ -39,7 +39,10 @@ class Squiz_Sniffs_Commenting_BlockCommentSniff implements PHP_CodeSniffer_Sniff
      */
     public function register()
     {
-        return array(T_COMMENT);
+        return array(
+                T_COMMENT,
+                T_DOC_COMMENT,
+               );
 
     }//end register()
 
@@ -62,11 +65,37 @@ class Squiz_Sniffs_Commenting_BlockCommentSniff implements PHP_CodeSniffer_Sniff
             return;
         }
 
+        // If this is a function/class/interface doc block comment, skip it.
+        // We are only interested in inline doc block comments.
+        if ($tokens[$stackPtr]['code'] === T_DOC_COMMENT) {
+            $nextToken = $phpcsFile->findNext(PHP_CodeSniffer_Tokens::$emptyTokens, ($stackPtr + 1), null, true);
+            $ignore    = array(
+                          T_CLASS,
+                          T_INTERFACE,
+                          T_FUNCTION,
+                          T_PUBLIC,
+                          T_PRIVATE,
+                          T_PROTECTED,
+                          T_STATIC,
+                          T_ABSTRACT,
+                          T_CONST,
+                         );
+            if (in_array($tokens[$nextToken]['code'], $ignore) === true) {
+                return;
+            }
+
+            $prevToken = $phpcsFile->findPrevious(PHP_CodeSniffer_Tokens::$emptyTokens, ($stackPtr - 1), null, true);
+            if ($tokens[$prevToken]['code'] === T_OPEN_TAG) {
+                return;
+            }
+        }//end if
+
         $commentLines = array($stackPtr);
         $nextComment  = $stackPtr;
         $lastLine     = $tokens[$stackPtr]['line'];
+
         // Construct the comment into an array.
-        while (($nextComment = $phpcsFile->findNext(array(T_COMMENT), ($nextComment + 1), null, false)) !== false) {
+        while (($nextComment = $phpcsFile->findNext($tokens[$stackPtr]['code'], ($nextComment + 1), null, false)) !== false) {
             if (($tokens[$nextComment]['line'] - 1) !== $lastLine) {
                 // Not part of the block.
                 break;
@@ -93,7 +122,8 @@ class Squiz_Sniffs_Commenting_BlockCommentSniff implements PHP_CodeSniffer_Sniff
             }
         }
 
-        if (trim($tokens[$stackPtr]['content']) !== '/*') {
+        $content = trim($tokens[$stackPtr]['content']);
+        if ($content !== '/*' && $content !== '/**') {
             $error = 'Block comment text must start on a new line';
             $phpcsFile->addError($error, $stackPtr);
             return;
@@ -151,7 +181,8 @@ class Squiz_Sniffs_Commenting_BlockCommentSniff implements PHP_CodeSniffer_Sniff
 
         // Finally, test the last line is correct.
         $lastIndex = (count($commentLines) - 1);
-        if (trim($tokens[$commentLines[$lastIndex]]['content']) !== '*/') {
+        $content   = trim($tokens[$commentLines[$lastIndex]]['content']);
+        if ($content !== '*/' && $content !== '**/') {
             $error = 'Comment closer must be on a new line';
             $phpcsFile->addError($error, $commentLines[$lastIndex]);
         } else {
@@ -169,9 +200,16 @@ class Squiz_Sniffs_Commenting_BlockCommentSniff implements PHP_CodeSniffer_Sniff
 
         // Check that the lines before and after this comment are blank.
         $contentBefore = $phpcsFile->findPrevious(T_WHITESPACE, ($stackPtr - 1), null, true);
-        if (($tokens[$stackPtr]['line'] - $tokens[$contentBefore]['line']) < 2) {
-            $error = 'Empty line required before block comment';
-            $phpcsFile->addError($error, $stackPtr);
+        if ($tokens[$contentBefore]['code'] === T_OPEN_CURLY_BRACKET) {
+            if (($tokens[$stackPtr]['line'] - $tokens[$contentBefore]['line']) < 1) {
+                $error = 'Empty line not required before block comment';
+                $phpcsFile->addError($error, $stackPtr);
+            }
+        } else {
+            if (($tokens[$stackPtr]['line'] - $tokens[$contentBefore]['line']) < 2) {
+                $error = 'Empty line required before block comment';
+                $phpcsFile->addError($error, $stackPtr);
+            }
         }
 
         $commentCloser = $commentLines[$lastIndex];
