@@ -10,7 +10,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: DocCommentAlignmentSniff.php,v 1.5 2008/01/12 13:47:32 squiz Exp $
+ * @version   CVS: $Id: DocCommentAlignmentSniff.php,v 1.7 2008/02/06 22:48:09 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -25,7 +25,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.0.1
+ * @version   Release: 1.1.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_Commenting_DocCommentAlignmentSniff implements PHP_CodeSniffer_Sniff
@@ -39,9 +39,7 @@ class Squiz_Sniffs_Commenting_DocCommentAlignmentSniff implements PHP_CodeSniffe
      */
     public function register()
     {
-        return array(
-                T_DOC_COMMENT,
-               );
+        return array(T_DOC_COMMENT);
 
     }//end register()
 
@@ -50,8 +48,8 @@ class Squiz_Sniffs_Commenting_DocCommentAlignmentSniff implements PHP_CodeSniffe
      * Processes this test, when one of its tokens is encountered.
      *
      * @param PHP_CodeSniffer_File $phpcsFile The file being scanned.
-     * @param int                  $stackPtr  The position of the current token in the
-     *                                        stack passed in $tokens.
+     * @param int                  $stackPtr  The position of the current token
+     *                                         in the stack passed in $tokens.
      *
      * @return void
      */
@@ -59,6 +57,26 @@ class Squiz_Sniffs_Commenting_DocCommentAlignmentSniff implements PHP_CodeSniffe
     {
         $tokens = $phpcsFile->getTokens();
 
+        // We are only interested in function/class/interface doc block comments.
+        $nextToken = $phpcsFile->findNext(PHP_CodeSniffer_Tokens::$emptyTokens, ($stackPtr + 1), null, true);
+        $ignore    = array(
+                      T_CLASS,
+                      T_INTERFACE,
+                      T_FUNCTION,
+                      T_PUBLIC,
+                      T_PRIVATE,
+                      T_PROTECTED,
+                      T_STATIC,
+                      T_ABSTRACT,
+                     );
+        if (in_array($tokens[$nextToken]['code'], $ignore) === false) {
+            // Could be a file comment.
+            $prevToken = $phpcsFile->findPrevious(PHP_CodeSniffer_Tokens::$emptyTokens, ($stackPtr - 1), null, true);
+            if ($tokens[$prevToken]['code'] !== T_OPEN_TAG) {
+                return;
+            }
+        }
+
         // We only want to get the first comment in a block. If there is
         // a comment on the line before this one, return.
         $docComment = $phpcsFile->findPrevious(T_DOC_COMMENT, ($stackPtr - 1));
