@@ -10,7 +10,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: VariableCommentSniff.php,v 1.20 2008/01/23 00:16:35 squiz Exp $
+ * @version   CVS: $Id: VariableCommentSniff.php,v 1.21 2008/02/21 23:14:17 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -40,7 +40,7 @@ if (class_exists('PHP_CodeSniffer_CommentParser_MemberCommentParser', true) ===
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.0.1
+ * @version   Release: 1.1.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -112,9 +112,11 @@ class Squiz_Sniffs_Commenting_VariableCommentSniff extends PHP_CodeSniffer_Stand
 
         // Check for a comment description.
         $short = $comment->getShortComment();
+        $long  = '';
         if (trim($short) === '') {
             $error = 'Missing short description in variable doc comment';
             $phpcsFile->addError($error, $commentStart);
+            $newlineCount = 1;
         } else {
             // No extra newline before short description.
             $newlineCount = 0;
