@@ -10,7 +10,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: ForLoopDeclarationSniff.php,v 1.5 2007/07/23 01:47:53 squiz Exp $
+ * @version   CVS: $Id: ForLoopDeclarationSniff.php,v 1.8 2008/05/08 03:38:48 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -25,12 +25,22 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.0.1
+ * @version   Release: 1.1.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_ControlStructures_ForLoopDeclarationSniff implements PHP_CodeSniffer_Sniff
 {
 
+    /**
+     * A list of tokenizers this sniff supports.
+     *
+     * @var array
+     */
+    public $supportedTokenizers = array(
+                                   'PHP',
+                                   'JS',
+                                  );
+
 
     /**
      * Returns an array of tokens this test wants to listen for.
@@ -39,9 +49,7 @@ class Squiz_Sniffs_ControlStructures_ForLoopDeclarationSniff implements PHP_Code
      */
     public function register()
     {
-        return array(
-                T_FOR,
-               );
+        return array(T_FOR);
 
     }//end register()
 
@@ -61,6 +69,12 @@ class Squiz_Sniffs_ControlStructures_ForLoopDeclarationSniff implements PHP_Code
         $errors = array();
 
         $openingBracket = $phpcsFile->findNext(T_OPEN_PARENTHESIS, $stackPtr);
+        if ($openingBracket === false) {
+            $error = 'Possible parse error: no opening parenthesis for FOR keyword';
+            $phpcsFile->addWarning($error, $stackPtr);
+            return;
+        }
+
         $closingBracket = $tokens[$openingBracket]['parenthesis_closer'];
 
         if ($tokens[($openingBracket + 1)]['code'] === T_WHITESPACE) {
@@ -72,34 +86,39 @@ class Squiz_Sniffs_ControlStructures_ForLoopDeclarationSniff implements PHP_Code
         }
 
         $firstSemicolon  = $phpcsFile->findNext(T_SEMICOLON, $openingBracket);
-        $secondSemicolon = $phpcsFile->findNext(T_SEMICOLON, ($firstSemicolon + 1));
 
         // Check whitespace around each of the tokens.
-        if ($tokens[($firstSemicolon - 1)]['code'] === T_WHITESPACE) {
-            $errors[] = 'Space found before first semicolon of FOR loop';
-        }
-
-        if ($tokens[($firstSemicolon + 1)]['code'] !== T_WHITESPACE) {
-            $errors[] = 'Expected 1 space after first semicolon of FOR loop; 0 found';
-        } else {
-            if (strlen($tokens[($firstSemicolon + 1)]['content']) !== 1) {
-                $spaces   = strlen($tokens[($firstSemicolon + 1)]['content']);
-                $errors[] = "Expected 1 space after first semicolon of FOR loop; $spaces found";
+        if ($firstSemicolon !== false) {
+            if ($tokens[($firstSemicolon - 1)]['code'] === T_WHITESPACE) {
+                $errors[] = 'Space found before first semicolon of FOR loop';
             }
-        }
 
-        if ($tokens[($secondSemicolon - 1)]['code'] === T_WHITESPACE) {
-            $errors[] = 'Space found before second semicolon of FOR loop';
-        }
-
-        if ($tokens[($secondSemicolon + 1)]['code'] !== T_WHITESPACE) {
-            $errors[] = 'Expected 1 space after second semicolon of FOR loop; 0 found';
-        } else {
-            if (strlen($tokens[($secondSemicolon + 1)]['content']) !== 1) {
-                $spaces   = strlen($tokens[($firstSemicolon + 1)]['content']);
-                $errors[] = "Expected 1 space after second semicolon of FOR loop; $spaces found";
+            if ($tokens[($firstSemicolon + 1)]['code'] !== T_WHITESPACE) {
+                $errors[] = 'Expected 1 space after first semicolon of FOR loop; 0 found';
+            } else {
+                if (strlen($tokens[($firstSemicolon + 1)]['content']) !== 1) {
+                    $spaces   = strlen($tokens[($firstSemicolon + 1)]['content']);
+                    $errors[] = "Expected 1 space after first semicolon of FOR loop; $spaces found";
+                }
             }
-        }
+
+            $secondSemicolon = $phpcsFile->findNext(T_SEMICOLON, ($firstSemicolon + 1));
+
+            if ($secondSemicolon !== false) {
+                if ($tokens[($secondSemicolon - 1)]['code'] === T_WHITESPACE) {
+                    $errors[] = 'Space found before second semicolon of FOR loop';
+                }
+
+                if ($tokens[($secondSemicolon + 1)]['code'] !== T_WHITESPACE) {
+                    $errors[] = 'Expected 1 space after second semicolon of FOR loop; 0 found';
+                } else {
+                    if (strlen($tokens[($secondSemicolon + 1)]['content']) !== 1) {
+                        $spaces   = strlen($tokens[($firstSemicolon + 1)]['content']);
+                        $errors[] = "Expected 1 space after second semicolon of FOR loop; $spaces found";
+                    }
+                }
+            }//end if
+        }//end if
 
         foreach ($errors as $error) {
             $phpcsFile->addError($error, $stackPtr);
