@@ -10,7 +10,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: OperatorBracketSniff.php,v 1.7 2007/07/23 01:47:53 squiz Exp $
+ * @version   CVS: $Id: OperatorBracketSniff.php,v 1.10 2008/03/17 03:52:43 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -25,12 +25,22 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.0.1
+ * @version   Release: 1.1.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_Formatting_OperatorBracketSniff implements PHP_CodeSniffer_Sniff
 {
 
+    /**
+     * A list of tokenizers this sniff supports.
+     *
+     * @var array
+     */
+    public $supportedTokenizers = array(
+                                   'PHP',
+                                   'JS',
+                                  );
+
 
     /**
      * Returns an array of tokens this test wants to listen for.
@@ -66,19 +76,19 @@ class Squiz_Sniffs_Formatting_OperatorBracketSniff implements PHP_CodeSniffer_Sn
         // the minus sign being used to assign a negative number to a variable.
         if ($tokens[$stackPtr]['code'] === T_MINUS) {
             // Check to see if we are trying to return -n.
-            $prev = $phpcsFile->findPrevious(array(T_WHITESPACE, T_COMMENT), ($stackPtr - 1), null, true);
-
+            $prev = $phpcsFile->findPrevious(PHP_CodeSniffer_Tokens::$emptyTokens, ($stackPtr - 1), null, true);
             if ($tokens[$prev]['code'] === T_RETURN) {
                 return;
             }
 
             $number = $phpcsFile->findNext(T_WHITESPACE, ($stackPtr + 1), null, true);
-            if ($tokens[$number]['code'] === T_LNUMBER) {
+            if ($tokens[$number]['code'] === T_LNUMBER || $tokens[$number]['code'] === T_DNUMBER) {
                 $previous = $phpcsFile->findPrevious(T_WHITESPACE, ($stackPtr - 1), null, true);
                 if ($previous !== false) {
                     $isAssignment = in_array($tokens[$previous]['code'], PHP_CodeSniffer_Tokens::$assignmentTokens);
                     $isEquality   = in_array($tokens[$previous]['code'], PHP_CodeSniffer_Tokens::$equalityTokens);
-                    if ($isAssignment === true || $isEquality === true) {
+                    $isComparison = in_array($tokens[$previous]['code'], PHP_CodeSniffer_Tokens::$comparisonTokens);
+                    if ($isAssignment === true || $isEquality === true || $isComparison === true) {
                         // This is a negative assignment or comparion.
                         // We need to check that the minus and the number are
                         // adjacent.
@@ -95,8 +105,8 @@ class Squiz_Sniffs_Formatting_OperatorBracketSniff implements PHP_CodeSniffer_Sn
 
         $lastBracket = false;
         if (isset($tokens[$stackPtr]['nested_parenthesis']) === true) {
-            $parenthesis = array_reverse(array_keys($tokens[$stackPtr]['nested_parenthesis']));
-            foreach ($parenthesis as $bracket) {
+            $parenthesis = array_reverse($tokens[$stackPtr]['nested_parenthesis'], true);
+            foreach ($parenthesis as $bracket => $endBracket) {
                 $prevToken = $phpcsFile->findPrevious(T_WHITESPACE, ($bracket - 1), null, true);
                 $prevCode  = $tokens[$prevToken]['code'];
 
@@ -107,13 +117,51 @@ class Squiz_Sniffs_Formatting_OperatorBracketSniff implements PHP_CodeSniffer_Sn
                 }
 
                 if ($prevCode === T_STRING) {
-                    // This operation is inside a function call, but has
-                    // no bracket of it's own.
-                    break;
-                }
+                    // We allow very simple operations to not be bracketed:
+                    // ceil($one / $two);
+                    $allowed = array(
+                                T_VARIABLE,
+                                T_LNUMBER,
+                                T_DNUMBER,
+                                T_STRING,
+                                T_WHITESPACE,
+                               );
+
+                    for ($prev = ($stackPtr - 1); $prev > $bracket; $prev--) {
+                        if (in_array($tokens[$prev]['code'], $allowed) === true) {
+                            continue;
+                        }
+
+                        if ($tokens[$prev]['code'] === T_CLOSE_PARENTHESIS) {
+                            $prev = $tokens[$prev]['parenthesis_opener'];
+                        } else {
+                            break;
+                        }
+                    }
+
+                    if ($prev !== $bracket) {
+                        break;
+                    }
+
+                    for ($next = ($stackPtr + 1); $next < $endBracket; $next++) {
+                        if (in_array($tokens[$next]['code'], $allowed) === true) {
+                            continue;
+                        }
+
+                        if ($tokens[$next]['code'] === T_OPEN_PARENTHESIS) {
+                            $next = $tokens[$next]['parenthesis_closer'];
+                        } else {
+                            break;
+                        }
+                    }
+
+                    if ($next !== $endBracket) {
+                        break;
+                    }
+                }//end if
 
                 if (in_array($prevCode, PHP_CodeSniffer_Tokens::$scopeOpeners) === true) {
-                    // This operation is inside an a control strucutre like FOREACH
+                    // This operation is inside an a control structure like FOREACH
                     // or IF, but has no bracket of it's own.
                     break;
                 }
@@ -121,7 +169,7 @@ class Squiz_Sniffs_Formatting_OperatorBracketSniff implements PHP_CodeSniffer_Sn
                 if ($prevCode === T_OPEN_PARENTHESIS) {
                     // These are two open parenthesis in a row. If the current
                     // one doesn't enclose the operator, go to the previous one.
-                    if ($tokens[$bracket]['parenthesis_closer'] < $stackPtr) {
+                    if ($endBracket < $stackPtr) {
                         continue;
                     }
                 }
