@@ -10,7 +10,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: ClosingDeclarationCommentUnitTest.php,v 1.1 2006/12/18 23:39:25 squiz Exp $
+ * @version   CVS: $Id: ClosingDeclarationCommentUnitTest.php,v 1.2 2008/05/08 03:58:12 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -26,7 +26,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.0.1
+ * @version   Release: 1.1.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Tests_Commenting_ClosingDeclarationCommentUnitTest extends AbstractSniffUnitTest
@@ -66,7 +66,9 @@ class Squiz_Tests_Commenting_ClosingDeclarationCommentUnitTest extends AbstractS
      */
     public function getWarningList()
     {
-        return array();
+        return array(
+                71 => 1,
+               );
 
     }//end getWarningList()
 
