@@ -10,7 +10,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: ForLoopDeclarationUnitTest.php,v 1.4 2007/06/26 01:18:51 squiz Exp $
+ * @version   CVS: $Id: ForLoopDeclarationUnitTest.php,v 1.6 2008/02/19 03:36:11 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -26,7 +26,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.0.1
+ * @version   Release: 1.1.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Tests_ControlStructures_ForLoopDeclarationUnitTest extends AbstractSniffUnitTest
@@ -39,17 +39,35 @@ class Squiz_Tests_ControlStructures_ForLoopDeclarationUnitTest extends AbstractS
      * The key of the array should represent the line number and the value
      * should represent the number of errors that should occur on that line.
      *
+     * @param string $testFile The name of the file being tested.
+     *
      * @return array(int => int)
      */
-    public function getErrorList()
+    public function getErrorList($testFile='ForLoopDeclarationUnitTest.inc')
     {
-        return array(
+        switch ($testFile) {
+        case 'ForLoopDeclarationUnitTest.inc':
+            return array(
                 8  => 2,
                 11 => 2,
                 14 => 2,
                 17 => 2,
                 21 => 6,
                );
+             break;
+        case 'ForLoopDeclarationUnitTest.js':
+            return array(
+                6  => 2,
+                9  => 2,
+                12 => 2,
+                15 => 2,
+                19 => 6,
+               );
+             break;
+        default:
+            return array();
+            break;
+        }//end switch
 
     }//end getErrorList()
 
